==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Test/Gui/Resources/translations/Test_pt-BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>Teste de unidade do FreeCAD</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Falhas e erros</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descrição</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Início</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+I</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>A&amp;juda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>S&amp;obre</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+O</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Fechar</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+F</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Ocioso</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progresso</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Faltando:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Erros:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Falhas:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Executar:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Teste</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selecione o nome do teste:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre o teste de unidade do FreeCAD</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

O teste de unidade do FreeCAD é parte do FreeCAD e suporta o desenvolvimento de testes de unidade para módulos próprios.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Digite o nome de um objeto que pode ser chamado que, quando chamado, vai retornar um TestCase. Clique "Iniciar", e o teste assim produzido será executado. Dê um duplo clique sobre um erro na árvore para ver mais informações sobre ele, incluindo o rastreamento de pilha.</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Test/Gui/Resources/translations/Test_pt-BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt-BR" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <source>FreeCAD UnitTest</source>
      <translation>Teste de unidade do FreeCAD</translation>
    </message>
    <message>
      <source>Failures and errors</source>
      <translation>Falhas e erros</translation>
    </message>
    <message>
      <source>Description</source>
      <translation>Descrição</translation>
    </message>
    <message>
      <source>&amp;Start</source>
      <translation>&amp;Início</translation>
    </message>
    <message>
      <source>Alt+S</source>
      <translation>Alt+I</translation>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation>A&amp;juda</translation>
    </message>
    <message>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <source>&amp;About</source>
      <translation>S&amp;obre</translation>
    </message>
    <message>
      <source>Alt+A</source>
      <translation>Alt+O</translation>
    </message>
    <message>
      <source>&amp;Close</source>
      <translation>&amp;Fechar</translation>
    </message>
    <message>
      <source>Alt+C</source>
      <translation>Alt+F</translation>
    </message>
    <message>
      <source>Idle</source>
      <translation>Ocioso</translation>
    </message>
    <message>
      <source>Progress</source>
      <translation>Progresso</translation>
    </message>
    <message>
      <source>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</source>
      <translation>&lt;font color="#0000ff"&gt;0&lt;/font&gt;</translation>
    </message>
    <message>
      <source>Remaining:</source>
      <translation>Faltando:</translation>
    </message>
    <message>
      <source>Errors:</source>
      <translation>Erros:</translation>
    </message>
    <message>
      <source>Failures:</source>
      <translation>Falhas:</translation>
    </message>
    <message>
      <source>Run:</source>
      <translation>Executar:</translation>
    </message>
    <message>
      <source>Test</source>
      <translation>Teste</translation>
    </message>
    <message>
      <source>Select test name:</source>
      <translation>Selecione o nome do teste:</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre o teste de unidade do FreeCAD</translation>
    </message>
    <message>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for own modules.</source>
      <translation>Copyright (c) Werner Mayer

O teste de unidade do FreeCAD é parte do FreeCAD e suporta o desenvolvimento de testes de unidade próprios para módulos.</translation>
    </message>
    <message>
      <source>Enter the name of a callable object which, when called, will return a TestCase.Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it,including the stack trace.</source>
      <translation>Digite o nome de um objeto que pode ser chamado que, quando chamado, vai retornar um TestCase. Clique "Iniciar", e o teste assim produzido será executado. Dê um duplo clique sobre um erro na árvore para ver mais informações sobre ele, incluindo o rastreamento de pilha.</translation>
    </message>
  </context>
</TS>
